##  Value Mapping
For single- and multi-select fields, tags, and tag groups, value mapping lets you specify which values in one system should match with values in the other.
The Value Mappings button appears only for single- and multi-select fields, tags, and tag groups. To map values, click the Value Mappings button, and in the resulting modal, add and match the values between both systems.
